@@ -228,7 +228,8 @@ class HelpOutput(object):
 
     def plot_area_monthly_avg(self, figname: str = None,
                               year_from: int = -np.inf,
-                              year_to: int = np.inf) -> Figure:
+                              year_to: int = np.inf,
+                              fig_title: str = None) -> Figure:
         """
         Plot the monthly average values of the water budget in mm/month
         for the whole study area.
@@ -245,6 +246,8 @@ class HelpOutput(object):
         year_to : int, optional
             Maximum year of the period over which the average monthly values
             are calculated. The default is np.inf.
+        fig_title : str, optional
+            A title to add at the top of the figure.
 
         Returns
         -------
@@ -281,6 +284,10 @@ class HelpOutput(object):
             numpoints=1, fontsize=12, frameon=False, borderaxespad=0,
             loc='lower left', borderpad=0.5, bbox_to_anchor=(0, 1), ncol=2)
 
+        # Add the figure title if provided in argument.
+        if fig_title is not None:
+            fig.suptitle(fig_title, fontsize=16)
+
         # Add note about year considered for the hydrologic budget.
         masked_years = self.data['years'][mask_years]
         year_min = masked_years.min()
@@ -299,6 +306,9 @@ class HelpOutput(object):
         ax.text(0, y0, text, transform=ax.transAxes + offset,
                 va='top', ha='left')
 
+        # We call tight_layout two times to make sure the layout is
+        # adjusted correctly.
+        fig.tight_layout()
         fig.tight_layout()
 
         # Save figure to file.
@@ -309,7 +319,8 @@ class HelpOutput(object):
 
     def plot_area_yearly_avg(self, figname: str = None,
                              year_from: int = -np.inf,
-                             year_to: int = np.inf) -> Figure:
+                             year_to: int = np.inf,
+                             fig_title: str = None) -> Figure:
         """
         Plot the yearly average values of the water budget in mm/year
         for the whole study area.
@@ -326,13 +337,15 @@ class HelpOutput(object):
         year_to : int, optional
             Maximum year of the period over which the average annual values
             are calculated. The default is np.inf.
+        fig_title : str, optional
+            A title to add at the top of the figure.
 
         Returns
         -------
         Figure
             The matplotlib figure instance created by this method.
         """
-        fig, ax = self._create_figure(fsize=(9, 5))
+        fig, ax = self._create_figure(fsize=(9, 5.5))
 
         text_offset = transforms.ScaledTranslation(
             0, 3/72, fig.dpi_scale_trans)
@@ -382,6 +395,10 @@ class HelpOutput(object):
             loc='lower left', borderpad=0.5, bbox_to_anchor=(0, 1, 1, 1),
             ncol=2)
 
+        # Add the figure title if provided in argument.
+        if fig_title is not None:
+            fig.suptitle(fig_title, fontsize=16)
+
         # Add note about year considered for the hydrologic budget.
         masked_years = self.data['years'][mask_years]
         year_min = masked_years.min()
@@ -400,6 +417,9 @@ class HelpOutput(object):
         ax.text(0, y0, text, transform=ax.transAxes + offset,
                 va='top', ha='left')
 
+        # We call tight_layout two times to make sure the layout is
+        # adjusted correctly.
+        fig.tight_layout()
         fig.tight_layout()
 
         if figname is not None:
@@ -409,7 +429,8 @@ class HelpOutput(object):
 
     def plot_area_yearly_series(self, figname: str = None,
                                 year_from: int = -np.inf,
-                                year_to: int = np.inf) -> Figure:
+                                year_to: int = np.inf,
+                                fig_title: str = None) -> Figure:
         """
         Plot the yearly values of the water budget in mm/year calculated
         over the whole study area.
@@ -426,6 +447,8 @@ class HelpOutput(object):
         year_to : int, optional
             Maximum year of the period over which the annual values
             are calculated. The default is np.inf.
+        fig_title : str, optional
+            A title to add at the top of the figure.
 
         Returns
         -------
@@ -466,6 +489,15 @@ class HelpOutput(object):
                   borderaxespad=0, loc='lower left', borderpad=0.5,
                   bbox_to_anchor=(0, 1), ncol=2)
 
+        # Add the figure title if provided in argument.
+        if fig_title is not None:
+            fig.suptitle(fig_title, fontsize=16)
+
+        # We call tight_layout two times to make sure the layout is
+        # adjusted correctly.
+        fig.tight_layout()
+        fig.tight_layout()
+
         if figname is not None:
             fig.savefig(figname)
 
